[atk] introspection: merge fixes from Vala bindings



commit acd2335095bf859d35332db6fdc9c54b53773918
Author: Evan Nemerson <evan coeus-group com>
Date:   Tue Oct 23 18:21:41 2012 -0700

    introspection: merge fixes from Vala bindings
    
    https://bugzilla.gnome.org/show_bug.cgi?id=686746

 atk/atkdocument.c      |    4 ++++
 atk/atkhyperlink.c     |    2 +-
 atk/atkhyperlink.h     |    2 +-
 atk/atkhyperlinkimpl.c |   12 ++++++------
 atk/atkhyperlinkimpl.h |    2 +-
 atk/atkobject.h        |   12 ++++++------
 atk/atkrelation.c      |    5 +++--
 atk/atkrelationset.h   |    2 +-
 atk/atkstateset.c      |    4 ++--
 atk/atktext.c          |   24 +++++++++++++-----------
 atk/atktext.h          |    4 ++--
 atk/atkutil.h          |    4 ++--
 12 files changed, 42 insertions(+), 35 deletions(-)
---
diff --git a/atk/atkdocument.c b/atk/atkdocument.c
index 01d0111..a60d32f 100755
--- a/atk/atkdocument.c
+++ b/atk/atkdocument.c
@@ -154,6 +154,7 @@ atk_document_get_document (AtkDocument *document)
  * Returns: a UTF-8 string indicating the POSIX-style LC_MESSAGES
  *          locale of the document content as a whole, or NULL if
  *          the document content does not specify a locale.
+ * Virtual: get_document_locale
  **/
 const gchar *
 atk_document_get_locale (AtkDocument *document)
@@ -187,6 +188,7 @@ atk_document_get_locale (AtkDocument *document)
  * Returns: (transfer none): An AtkAttributeSet containing the explicitly
  *          set name-value-pair attributes associated with this document
  *          as a whole.
+ * Virtual: get_document_attributes
  **/
 AtkAttributeSet *
 atk_document_get_attributes (AtkDocument *document)
@@ -218,6 +220,7 @@ atk_document_get_attributes (AtkDocument *document)
  * Returns: a string value associated with the named attribute for this
  *    document, or NULL if a value for #attribute_name has not been specified
  *    for this document.
+ * Virtual: get_document_attribute_value
  */
 const gchar *
 atk_document_get_attribute_value (AtkDocument *document, 
@@ -251,6 +254,7 @@ atk_document_get_attribute_value (AtkDocument *document,
  * Returns: TRUE if #value is successfully associated with #attribute_name
  *          for this document, FALSE otherwise (e.g. if the document does not
  *          allow the attribute to be modified).
+ * Virtual: set_document_attribute
  */
 gboolean
 atk_document_set_attribute_value (AtkDocument *document, 
diff --git a/atk/atkhyperlink.c b/atk/atkhyperlink.c
index 3fc902d..69a971d 100755
--- a/atk/atkhyperlink.c
+++ b/atk/atkhyperlink.c
@@ -359,7 +359,7 @@ atk_hyperlink_get_n_anchors (AtkHyperlink *link)
  *
  * Since: 1.4
  *
- * @Deprecated: This method is deprecated since ATK version 1.8.
+ * Deprecated: This method is deprecated since ATK version 1.8.
  * Please use ATK_STATE_SELECTED to indicate when a hyperlink within a
  * Hypertext container is selected.
  *
diff --git a/atk/atkhyperlink.h b/atk/atkhyperlink.h
index c85a8b3..2e8a529 100755
--- a/atk/atkhyperlink.h
+++ b/atk/atkhyperlink.h
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
  */
 
 /**
- *AtkHyperlinkStateFlags
+ *AtkHyperlinkStateFlags:
  * ATK_HYPERLINK_IS_INLINE: Link is inline
  *
  *Describes the type of link
diff --git a/atk/atkhyperlinkimpl.c b/atk/atkhyperlinkimpl.c
index 45ee44e..e4ad10f 100644
--- a/atk/atkhyperlinkimpl.c
+++ b/atk/atkhyperlinkimpl.c
@@ -42,7 +42,7 @@ atk_hyperlink_impl_get_type (void)
 
 /**
  * atk_hyperlink_impl_get_hyperlink:
- * @obj: a GObject instance that implements AtkHyperlinkImplIface
+ * @impl: a #GObject instance that implements AtkHyperlinkImplIface
  *
  * Gets the hyperlink associated with this object.
  *
@@ -52,18 +52,18 @@ atk_hyperlink_impl_get_type (void)
  * Since: 1.12
  **/
 AtkHyperlink *
-atk_hyperlink_impl_get_hyperlink (AtkHyperlinkImpl *obj)
+atk_hyperlink_impl_get_hyperlink (AtkHyperlinkImpl *impl)
 {
   AtkHyperlinkImplIface *iface;
 
-  g_return_val_if_fail (obj != NULL, NULL);
-  g_return_val_if_fail (ATK_IS_HYPERLINK_IMPL (obj), NULL);
+  g_return_val_if_fail (impl != NULL, NULL);
+  g_return_val_if_fail (ATK_IS_HYPERLINK_IMPL (impl), NULL);
 
-  iface = ATK_HYPERLINK_IMPL_GET_IFACE (obj);
+  iface = ATK_HYPERLINK_IMPL_GET_IFACE (impl);
 
   if (iface->get_hyperlink)
     {
-      return (iface->get_hyperlink) (obj);
+      return (iface->get_hyperlink) (impl);
     }
   return NULL;
 }
diff --git a/atk/atkhyperlinkimpl.h b/atk/atkhyperlinkimpl.h
index d07a2fc..3e0f589 100644
--- a/atk/atkhyperlinkimpl.h
+++ b/atk/atkhyperlinkimpl.h
@@ -68,7 +68,7 @@ struct _AtkHyperlinkImplIface
 
 GType            atk_hyperlink_impl_get_type (void);
 
-AtkHyperlink    *atk_hyperlink_impl_get_hyperlink (AtkHyperlinkImpl *obj);
+AtkHyperlink    *atk_hyperlink_impl_get_hyperlink (AtkHyperlinkImpl *impl);
 
 G_END_DECLS
 
diff --git a/atk/atkobject.h b/atk/atkobject.h
index bbfebbf..0fa91be 100755
--- a/atk/atkobject.h
+++ b/atk/atkobject.h
@@ -351,15 +351,15 @@ typedef struct _AtkStateSet               AtkStateSet;
  * @old_value: The old property value, NULL; in some contexts this value is undefined (see note below).
  * @new_value: The new value of the named property.
  *
- * @note: For most properties the old_value field of AtkPropertyValues will
- * not contain a valid value.
+ * Note: for most properties the old_value field of #AtkPropertyValues
+ * will not contain a valid value.
  *
  * Currently, the only property for which old_value is used is
  * accessible-state; for instance if there is a focus state the
  * property change handler will be called for the object which lost the focus
- * with the old_value containing an AtkState value corresponding to focused
+ * with the old_value containing an #AtkState value corresponding to focused
  * and the property change handler will be called for the object which
- * received the focus with the new_value containing an AtkState value
+ * received the focus with the new_value containing an #AtkState value
  * corresponding to focused.
  *
  **/
@@ -372,7 +372,7 @@ struct _AtkPropertyValues
 
 typedef struct _AtkPropertyValues        AtkPropertyValues;
 
-typedef gboolean (*AtkFunction)          (gpointer data); 
+typedef gboolean (*AtkFunction)          (gpointer user_data);
 /*
  * For most properties the old_value field of AtkPropertyValues will
  * not contain a valid value.
@@ -385,7 +385,7 @@ typedef gboolean (*AtkFunction)          (gpointer data);
  * received the focus with the new_value containing an AtkState value
  * corresponding to focused.
  */
-typedef void (*AtkPropertyChangeHandler) (AtkObject*, AtkPropertyValues*);
+typedef void (*AtkPropertyChangeHandler) (AtkObject* obj, AtkPropertyValues* vals);
 
 
 struct _AtkObject
diff --git a/atk/atkrelation.c b/atk/atkrelation.c
index 171d4f3..cc1807e 100755
--- a/atk/atkrelation.c
+++ b/atk/atkrelation.c
@@ -217,7 +217,8 @@ atk_relation_type_for_name (const gchar *name)
 
 /**
  * atk_relation_new:
- * @targets: an array of pointers to #AtkObjects  
+ * @targets: (array length=n_targets): an array of pointers to
+ *  #AtkObjects
  * @n_targets: number of #AtkObjects pointed to by @targets
  * @relationship: an #AtkRelationType with which to create the new
  *  #AtkRelation
@@ -282,7 +283,7 @@ atk_relation_get_relation_type (AtkRelation *relation)
  *
  * Gets the target list of @relation
  *
- * Returns: (transfer none): the target list of @relation
+ * Returns: (transfer none) (element-type Atk.Object): the target list of @relation
  **/
 GPtrArray*
 atk_relation_get_target (AtkRelation *relation)
diff --git a/atk/atkrelationset.h b/atk/atkrelationset.h
index e0b5449..2d97bf1 100755
--- a/atk/atkrelationset.h
+++ b/atk/atkrelationset.h
@@ -62,7 +62,7 @@ gboolean        atk_relation_set_contains             (AtkRelationSet  *set,
                                                        AtkRelationType relationship);
 gboolean        atk_relation_set_contains_target      (AtkRelationSet  *set,
                                                        AtkRelationType relationship,
-                                                       AtkObject       *targe);
+                                                       AtkObject       *target);
 void            atk_relation_set_remove               (AtkRelationSet  *set,
                                                        AtkRelation     *relation);
 void            atk_relation_set_add                  (AtkRelationSet  *set,
diff --git a/atk/atkstateset.c b/atk/atkstateset.c
index eabb9f9..001a980 100755
--- a/atk/atkstateset.c
+++ b/atk/atkstateset.c
@@ -129,7 +129,7 @@ atk_state_set_add_state (AtkStateSet   *set,
 /**
  * atk_state_set_add_states:
  * @set: an #AtkStateSet
- * @types: an array of #AtkStateType
+ * @types: (array length=n_types): an array of #AtkStateType
  * @n_types: The number of elements in the array
  *
  * Add the states for the specified types to the current state set.
@@ -195,7 +195,7 @@ atk_state_set_contains_state (AtkStateSet   *set,
 /**
  * atk_state_set_contains_states:
  * @set: an #AtkStateSet
- * @types: an array of #AtkStateType
+ * @types: (array length=n_types): an array of #AtkStateType
  * @n_types: The number of elements in the array
  *
  * Checks whether the states for all the specified types are in the 
diff --git a/atk/atktext.c b/atk/atktext.c
index 086dd18..edf0be7 100755
--- a/atk/atktext.c
+++ b/atk/atktext.c
@@ -295,8 +295,8 @@ atk_text_get_character_at_offset (AtkText      *text,
  * @text: an #AtkText
  * @offset: position
  * @boundary_type: An #AtkTextBoundary
- * @start_offset: the start offset of the returned string
- * @end_offset: the offset of the first character after the 
+ * @start_offset: (out): the start offset of the returned string
+ * @end_offset: (out): the offset of the first character after the
  *              returned substring
  *
  * Gets the specified text.
@@ -378,8 +378,8 @@ atk_text_get_text_after_offset (AtkText          *text,
  * @text: an #AtkText
  * @offset: position
  * @boundary_type: An #AtkTextBoundary
- * @start_offset: the start offset of the returned string
- * @end_offset: the offset of the first character after the 
+ * @start_offset: (out): the start offset of the returned string
+ * @end_offset: (out): the offset of the first character after the
  *              returned substring
  *
  * Gets the specified text.
@@ -465,8 +465,8 @@ atk_text_get_text_at_offset (AtkText          *text,
  * @text: an #AtkText
  * @offset: position
  * @boundary_type: An #AtkTextBoundary
- * @start_offset: the start offset of the returned string
- * @end_offset: the offset of the first character after the 
+ * @start_offset: (out): the start offset of the returned string
+ * @end_offset: (out): the offset of the first character after the
  *              returned substring
  *
  * Gets the specified text.
@@ -641,8 +641,8 @@ atk_text_get_character_extents (AtkText *text,
  * text: an #AtkText
  * offset: the offset at which to get the attributes, -1 means the offset of
  *the character to be inserted at the caret location.
- * start_offset: the address to put the start offset of the range
- * end_offset: the address to put the end offset of the range
+ * start_offset: (out): the address to put the start offset of the range
+ * end_offset: (out): the address to put the end offset of the range
  *
  *Creates an #AtkAttributeSet which consists of the attributes explicitly
  *set at the position @offset in the text. @start_offset and @end_offset are
@@ -804,8 +804,8 @@ atk_text_get_n_selections (AtkText *text)
  * start of the text.  The selected region closest to the beginning
  * of the text region is assigned the number 0, etc.  Note that adding,
  * moving or deleting a selected region can change the numbering.
- * @start_offset: passes back the start position of the selected region
- * @end_offset: passes back the end position of (e.g. offset immediately past) 
+ * @start_offset: (out): passes back the start position of the selected region
+ * @end_offset: (out): passes back the end position of (e.g. offset immediately past)
  * the selected region
  *
  * Gets the text from the specified selection.
@@ -1016,6 +1016,7 @@ atk_text_get_range_extents (AtkText          *text,
  *
  * Returns: (array zero-terminated=1): Array of AtkTextRange. The last
  *          element of the array returned by this function will be NULL.
+ * Virtual: get_bounded_ranges
  **/
 AtkTextRange**
 atk_text_get_bounded_ranges (AtkText          *text,
@@ -1384,7 +1385,8 @@ atk_text_real_get_bounded_ranges (AtkText          *text,
 
 /**
  * atk_text_free_ranges:
- * @ranges: A pointer to an array of  #AtkTextRange which is to be freed.
+ * @ranges: (array): A pointer to an array of #AtkTextRange which is
+ *   to be freed.
  *
  * Frees the memory associated with an array of AtkTextRange. It is assumed
  * that the array was returned by the function atk_text_get_bounded_ranges
diff --git a/atk/atktext.h b/atk/atktext.h
index 81ad312..0edfcc0 100755
--- a/atk/atktext.h
+++ b/atk/atktext.h
@@ -31,7 +31,7 @@
 G_BEGIN_DECLS
 
 /**
- *AtkTextAttribute
+ *AtkTextAttribute:
  * ATK_TEXT_ATTR_INVALID: Invalid attribute
  * ATK_TEXT_ATTR_LEFT_MARGIN: The pixel width of the left margin
  * ATK_TEXT_ATTR_RIGHT_MARGIN: The pixel width of the right margin
@@ -177,7 +177,7 @@ struct _AtkTextRange {
 GType atk_text_range_get_type (void);
 
 /**
- *AtkTextClipType
+ *AtkTextClipType:
  * ATK_TEXT_CLIP_NONE: No clipping to be done
  * ATK_TEXT_CLIP_MIN: Text clipped by min coordinate is omitted
  * ATK_TEXT_CLIP_MAX: Text clipped by max coordinate is omitted
diff --git a/atk/atkutil.h b/atk/atkutil.h
index 6a527fe..ce7e21d 100755
--- a/atk/atkutil.h
+++ b/atk/atkutil.h
@@ -71,7 +71,7 @@ typedef void  (*AtkEventListenerInit) (void);
  * AtkKeySnoopFunc:
  * @event: an AtkKeyEventStruct containing information about the key event for which
  * notification is being given.
  * @func_data: a block of data which will be passed to the event listener, on notification.
  *
  * An #AtkKeySnoopFunc is a type of callback which is called whenever a key event occurs, 
  * if registered via atk_add_key_event_listener.  It allows for pre-emptive 
@@ -84,7 +84,7 @@ typedef void  (*AtkEventListenerInit) (void);
  * see atk_add_key_event_listener.
  **/
 typedef gint  (*AtkKeySnoopFunc)  (AtkKeyEventStruct *event,
-				   gpointer func_data);
+				   gpointer user_data);
 
 /**
  * AtkKeyEventStruct:
@@ -71,7 +71,7 @@ typedef void  (*AtkEventListenerInit) (void);
  * @event: an AtkKeyEventStruct containing information about the key event for which
  * notification is being given.
- * @func_data: a block of data which will be passed to the event listener, on notification.
+ * @user_data: a block of data which will be passed to the event listener, on notification.
  *
  * An #AtkKeySnoopFunc is a type of callback which is called whenever a key event occurs, 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]